@@ -25,7 +25,11 @@
 
 #ifndef POOL_PROCESS_CONTEXT_H
 #define POOL_PROCESS_CONTEXT_H
-#include "pool.h"
+
+//#include "pool.h"
+#include "pcp/libpcp_ext.h"
+#include "utils/pool_signal.h"
+
 
 /*
  * Child process context:
